<?php $TRANSLATIONS = array(
"Sunday" => "Nedelja",
"Monday" => "Ponedeljak",
"Tuesday" => "Utorak",
"Wednesday" => "Sreda",
"Thursday" => "Četvrtak",
"Friday" => "Petak",
"Saturday" => "Subota",
"January" => "Januar",
"February" => "Februar",
"March" => "Mart",
"April" => "April",
"May" => "Maj",
"June" => "Jun",
"July" => "Jul",
"August" => "Avgust",
"September" => "Septembar",
"October" => "Oktobar",
"November" => "Novembar",
"December" => "Decembar",
"Settings" => "Podešavanja",
"Cancel" => "Otkaži",
"Password" => "Lozinka",
"You will receive a link to reset your password via Email." => "Dobićete vezu za resetovanje lozinke putem e-pošte.",
"Username" => "Korisničko ime",
"Request reset" => "Zahtevaj resetovanje",
"Your password was reset" => "Vaša lozinka je resetovana",
"New password" => "Nova lozinka",
"Reset password" => "Resetuj lozinku",
"Personal" => "Lična",
"Users" => "Korisnici",
"Apps" => "Programi",
"Admin" => "Adninistracija",
"Help" => "Pomoć",
"Cloud not found" => "Oblak nije nađen",
"Create an <strong>admin account</strong>" => "Napravi <strong>administrativni nalog</strong>",
"Advanced" => "Napredno",
"Data folder" => "Facikla podataka",
"Configure the database" => "Podešavanje baze",
"will be used" => "će biti korišćen",
"Database user" => "Korisnik baze",
"Database password" => "Lozinka baze",
"Database name" => "Ime baze",
"Database host" => "Domaćin baze",
"Finish setup" => "Završi podešavanje",
"Log out" => "Odjava",
"Lost your password?" => "Izgubili ste lozinku?",
"remember" => "upamti",
"prev" => "prethodno",
"next" => "sledeće"
);
